@@ -30,6 +30,7 @@ impl Reshape {
     pub fn new_with_options(
         host: &str,
         port: u16,
+        database: &str,
         username: &str,
         password: &str,
     ) -> anyhow::Result<Reshape> {
@@ -38,6 +39,7 @@ impl Reshape {
             .host(host)
             .port(port)
             .user(username)
+            .dbname(database)
             .password(password);
 
         Self::new_with_config(&config)
@@ -145,13 +147,15 @@ fn migrate(
 ) -> anyhow::Result<()> {
     // Make sure no migration is in progress
     if let State::InProgress { .. } = &state {
-        println!("Migration already in progress, please complete using 'reshape complete'");
+        println!(
+            "Migration already in progress, please complete using 'reshape migration complete'"
+        );
         return Ok(());
     }
 
     if let State::Completing { .. } = &state {
         println!(
-                    "Migration already in progress and has started completion, please finish using 'reshape complete'"
+                    "Migration already in progress and has started completion, please finish using 'reshape migration complete'"
                 );
         return Ok(());
     }
@@ -160,7 +164,6 @@ fn migrate(
     // with the already applied ones stored in the state. This will throw an error if the
     // two sets of migrations don't agree, for example if a new migration has been added
     // in between two existing ones.
-    let current_migration = state::current_migration(db)?;
     let remaining_migrations = state::remaining_migrations(db, migrations)?;
     if remaining_migrations.is_empty() {
         println!("No migrations left to apply");
@@ -175,8 +178,8 @@ fn migrate(
     {
         if existing_migrations != &remaining_migrations {
             return Err(anyhow!(
-                        "a previous migration seems to have failed without cleaning up. Please run `reshape abort` and then run migrate again."
-                    ));
+                "a previous migration seems to have failed without cleaning up. Please run `reshape migration abort` and then run migrate again."
+            ));
         }
     }
 
@@ -189,7 +192,8 @@ fn migrate(
 
     println!("Applying {} migrations\n", remaining_migrations.len());
 
-    helpers::set_up_helpers(db, &current_migration).context("failed to set up helpers")?;
+    let target_migration = remaining_migrations.last().unwrap().name.to_string();
+    helpers::set_up_helpers(db, &target_migration).context("failed to set up helpers")?;
 
     let mut new_schema = Schema::new();
     let mut last_migration_index = usize::MAX;
@@ -230,7 +234,7 @@ fn migrate(
         // Set to the Aborting state. This is to ensure that the failed
         // migration is fully aborted and nothing is left dangling.
         // If the abort is interrupted for any reason, the user can try again
-        // by running `reshape abort`.
+        // by running `reshape migration abort`.
         state.aborting(
             remaining_migrations.clone(),
             last_migration_index + 1,
@@ -244,7 +248,6 @@ fn migrate(
     }
 
     // Create schema and views for migration
-    let target_migration = remaining_migrations.last().unwrap().name.to_string();
     create_schema_for_migration(db, &target_migration, &new_schema)
         .with_context(|| format!("failed to create schema for migration {}", target_migration))?;
 
@@ -252,27 +255,14 @@ fn migrate(
     state.in_progress(remaining_migrations);
     state.save(db).context("failed to save in-progress state")?;
 
-    // If we started from a blank slate, we can finish the migration immediately
-    if current_migration.is_none() {
-        println!("Automatically completing migrations\n");
-        complete(db, state).context("failed to automatically complete migrations")?;
-
-        println!("Migrations complete:");
-        println!(
-            "  - Run '{}' from your application to use the latest schema",
-            schema_query_for_migration(&target_migration)
-        );
-    } else {
-        println!("Migrations have been applied and the new schema is ready for use:");
-        println!(
-            "  - Run '{}' from your application to use the latest schema",
-            schema_query_for_migration(&target_migration)
-        );
-        println!(
-                    "  - Run 'reshape complete' once your application has been updated and the previous schema is no longer in use"
-                );
-    }
-
+    println!("Migrations have been applied and the new schema is ready for use:");
+    println!(
+        "  - Run '{}' from your application to use the latest schema",
+        schema_query_for_migration(&target_migration)
+    );
+    println!(
+        "  - Run 'reshape migration complete' once your application has been updated and the previous schema is no longer in use"
+    );
     Ok(())
 }
 
@@ -293,7 +283,7 @@ fn complete(db: &mut DbConn, state: &mut State) -> anyhow::Result<()> {
                     current_action_index
                 } => (migrations, current_migration_index, current_action_index),
                 State::Aborting { .. } => {
-                    return Err(anyhow!("migration been aborted and can't be completed. Please finish using `reshape abort`."))
+                    return Err(anyhow!("migration been aborted and can't be completed. Please finish using `reshape migration abort`."))
                 }
                 State::Applying { .. } => {
                     return Err(anyhow!("a previous migration unexpectedly failed. Please run `reshape migrate` to try applying the migration again."))
@@ -421,7 +411,7 @@ fn abort(db: &mut DbConn, state: &mut State) -> anyhow::Result<()> {
             last_action_index,
         } => (migrations, last_migration_index, last_action_index),
         State::Completing { .. } => {
-            return Err(anyhow!("Migration completion has already been started. Please run `reshape complete` again to finish it."));
+            return Err(anyhow!("migration completion has already been started. Please run `reshape migration complete` again to finish it."));
         }
         State::Idle => {
             println!("No migration is in progress");
