@@ -12,22 +12,69 @@ use reshape::{
 use serde::{Deserialize, Serialize};
 
 #[derive(Parser)]
+#[clap(name = "Reshape", version, about)]
 struct Opts {
     #[clap(subcommand)]
     cmd: Command,
 }
 
 #[derive(Parser)]
+#[clap(about)]
 enum Command {
-    Migrate(MigrateOptions),
-    Complete(ConnectionOptions),
-    Remove(ConnectionOptions),
-    Abort(ConnectionOptions),
+    #[clap(subcommand)]
+    Migration(MigrationCommand),
+
+    #[clap(
+        about = "Output the query your application should use to select the right schema",
+        display_order = 2
+    )]
+    SchemaQuery(FindMigrationsOptions),
+
+    #[clap(
+        about = "Deprecated. Use `reshape schema-query` instead",
+        display_order = 3
+    )]
     GenerateSchemaQuery(FindMigrationsOptions),
+
+    #[clap(
+        about = "Deprecated. Use `reshape migration start` instead",
+        display_order = 4
+    )]
+    Migrate(MigrateOptions),
+    #[clap(
+        about = "Deprecated. Use `reshape migration complete` instead",
+        display_order = 5
+    )]
+    Complete(ConnectionOptions),
+    #[clap(
+        about = "Deprecated. Use `reshape migration abort` instead",
+        display_order = 6
+    )]
+    Abort(ConnectionOptions),
+}
+
+#[derive(Parser)]
+#[clap(about = "Commands for managing migrations", display_order = 1)]
+enum MigrationCommand {
+    #[clap(
+        about = "Starts a new migration, applying any migrations which haven't yet been applied",
+        display_order = 1
+    )]
+    Start(MigrateOptions),
+
+    #[clap(about = "Completes an in-progress migration", display_order = 2)]
+    Complete(ConnectionOptions),
+
+    #[clap(
+        about = "Aborts an in-progress migration without losing any data",
+        display_order = 3
+    )]
+    Abort(ConnectionOptions),
 }
 
 #[derive(Args)]
 struct MigrateOptions {
+    // Some comment
     #[clap(long, short)]
     complete: bool,
     #[clap(flatten)]
@@ -65,7 +112,7 @@ fn main() -> anyhow::Result<()> {
 
 fn run(opts: Opts) -> anyhow::Result<()> {
     match opts.cmd {
-        Command::Migrate(opts) => {
+        Command::Migration(MigrationCommand::Start(opts)) | Command::Migrate(opts) => {
             let mut reshape = reshape_from_connection_options(&opts.connection_options)?;
             let migrations = find_migrations(&opts.find_migrations_options)?;
             reshape.migrate(migrations)?;
@@ -77,20 +124,16 @@ fn run(opts: Opts) -> anyhow::Result<()> {
 
             Ok(())
         }
-        Command::Complete(opts) => {
+        Command::Migration(MigrationCommand::Complete(opts)) | Command::Complete(opts) => {
             let mut reshape = reshape_from_connection_options(&opts)?;
             reshape.complete()
         }
-        Command::Remove(opts) => {
-            let mut reshape = reshape_from_connection_options(&opts)?;
-            reshape.remove()
-        }
-        Command::Abort(opts) => {
+        Command::Migration(MigrationCommand::Abort(opts)) | Command::Abort(opts) => {
             let mut reshape = reshape_from_connection_options(&opts)?;
             reshape.abort()
         }
-        Command::GenerateSchemaQuery(find_migrations_options) => {
-            let migrations = find_migrations(&find_migrations_options)?;
+        Command::SchemaQuery(opts) | Command::GenerateSchemaQuery(opts) => {
+            let migrations = find_migrations(&opts)?;
             let query = migrations
                 .last()
                 .map(|migration| reshape::schema_query_for_migration(&migration.name));
@@ -102,13 +145,35 @@ fn run(opts: Opts) -> anyhow::Result<()> {
 }
 
 fn reshape_from_connection_options(opts: &ConnectionOptions) -> anyhow::Result<Reshape> {
-    let env_url = std::env::var("POSTGRES_URL").ok();
-    let url = env_url.as_ref().or_else(|| opts.url.as_ref());
+    // Load environment variables from .env file if it exists
+    dotenv::dotenv().ok();
 
-    match url {
-        Some(url) => Reshape::new(url),
-        None => Reshape::new_with_options(&opts.host, opts.port, &opts.username, &opts.password),
+    let url_env = std::env::var("DB_URL").ok();
+    let url = url_env.as_ref().or_else(|| opts.url.as_ref());
+
+    // Use the connection URL if it has been set
+    if let Some(url) = url {
+        return Reshape::new(url);
     }
+
+    let host_env = std::env::var("DB_HOST").ok();
+    let host = host_env.as_ref().unwrap_or_else(|| &opts.host);
+
+    let port = std::env::var("DB_PORT")
+        .ok()
+        .and_then(|port| port.parse::<u16>().ok())
+        .unwrap_or(opts.port);
+
+    let username_env = std::env::var("DB_USERNAME").ok();
+    let username = username_env.as_ref().unwrap_or_else(|| &opts.username);
+
+    let password_env = std::env::var("DB_PASSWORD").ok();
+    let password = password_env.as_ref().unwrap_or_else(|| &opts.password);
+
+    let database_env = std::env::var("DB_NAME").ok();
+    let database = database_env.as_ref().unwrap_or_else(|| &opts.database);
+
+    Reshape::new_with_options(host, port, database, username, password)
 }
 
 fn find_migrations(opts: &FindMigrationsOptions) -> anyhow::Result<Vec<Migration>> {
