@@ -103,7 +103,7 @@ impl Action for AlterColumn {
                 CREATE OR REPLACE FUNCTION {up_trigger}()
                 RETURNS TRIGGER AS $$
                 BEGIN
-                    IF reshape.is_old_schema() THEN
+                    IF NOT reshape.is_new_schema() THEN
                         DECLARE
                             {declarations}
                             {existing_column} public.{table}.{existing_column_real}%TYPE := NEW.{existing_column_real};
@@ -121,7 +121,7 @@ impl Action for AlterColumn {
                 CREATE OR REPLACE FUNCTION {down_trigger}()
                 RETURNS TRIGGER AS $$
                 BEGIN
-                    IF NOT reshape.is_old_schema() THEN
+                    IF reshape.is_new_schema() THEN
                         DECLARE
                             {declarations}
                             {existing_column} public.{table}.{temp_column}%TYPE := NEW.{temp_column};
@@ -187,7 +187,7 @@ impl Action for AlterColumn {
         // This constraint is set as NOT VALID so it doesn't apply to existing rows and
         // the existing rows don't need to be scanned under an exclusive lock.
         // Thanks to this, we can set the full column as NOT NULL later with minimal locking.
-        if !column.nullable {
+        if !self.changes.nullable.unwrap_or(column.nullable) {
             let query = format!(
                 r#"
                 ALTER TABLE "{table}"
