@@ -286,3 +286,20 @@ impl Schema {
         Ok(table)
     }
 }
+
+impl Table {
+    pub fn real_column_names<'a>(
+        &'a self,
+        columns: &'a [String],
+    ) -> impl Iterator<Item = &'a String> {
+        columns.iter().map(|name| {
+            self.get_column(name)
+                .map(|col| &col.real_name)
+                .unwrap_or(name)
+        })
+    }
+
+    pub fn get_column(&self, name: &str) -> Option<&Column> {
+        self.columns.iter().find(|column| column.name == name)
+    }
+}
