@@ -12,6 +12,7 @@ pub struct Test<'a> {
     second_migration: Option<Migration>,
     expect_failure: bool,
 
+    clear_fn: Option<fn(&mut Client) -> ()>,
     after_first_fn: Option<fn(&mut Client) -> ()>,
     intermediate_fn: Option<fn(&mut Client, &mut Client) -> ()>,
     after_completion_fn: Option<fn(&mut Client) -> ()>,
@@ -36,6 +37,7 @@ impl Test<'_> {
             first_migration: None,
             second_migration: None,
             expect_failure: false,
+            clear_fn: None,
             after_first_fn: None,
             intermediate_fn: None,
             after_completion_fn: None,
@@ -54,6 +56,12 @@ impl Test<'_> {
         self
     }
 
+    #[allow(dead_code)]
+    pub fn clear(&mut self, f: fn(&mut Client) -> ()) -> &mut Self {
+        self.clear_fn = Some(f);
+        self
+    }
+
     #[allow(dead_code)]
     pub fn after_first(&mut self, f: fn(&mut Client) -> ()) -> &mut Self {
         self.after_first_fn = Some(f);
@@ -115,6 +123,10 @@ impl Test<'_> {
         print_subheading("Clearing database");
         self.reshape.remove().unwrap();
 
+        if let Some(clear_fn) = self.clear_fn {
+            clear_fn(&mut self.old_db);
+        }
+
         // Apply first migration, will automatically complete
         print_subheading("Applying first migration");
         let first_migration = self
@@ -128,6 +140,9 @@ impl Test<'_> {
             .simple_query(&reshape::schema_query_for_migration(&first_migration.name))
             .unwrap();
 
+        // Automatically complete first migration
+        self.reshape.complete().unwrap();
+
         // Run setup function
         if let Some(after_first_fn) = self.after_first_fn {
             print_subheading("Running setup and first checks");
@@ -196,7 +211,7 @@ impl Test<'_> {
 }
 
 fn print_heading(text: &str) {
-    let delimiter = std::iter::repeat("=").take(50).collect::<String>();
+    let delimiter = std::iter::repeat("=").take(80).collect::<String>();
 
     println!();
     println!();
